pub enum HummockReadEpoch {
Committed(HummockEpoch),
BatchQueryCommitted(HummockEpoch, HummockVersionId),
NoWait(HummockEpoch),
Backup(HummockEpoch),
TimeTravel(HummockEpoch),
}Expand description
Package read epoch of hummock, it be used for wait_epoch
Variants
Committed(HummockEpoch)
We need to wait the committed_epoch of the read table
BatchQueryCommitted(HummockEpoch, HummockVersionId)
We need to wait the committed_epoch of the read table and also the hummock version to the version id
NoWait(HummockEpoch)
We don’t need to wait epoch, we usually do stream reading with it.
Backup(HummockEpoch)
We don’t need to wait epoch.
TimeTravel(HummockEpoch)
Implementations
Sourceimpl HummockReadEpoch
impl HummockReadEpoch
pub fn get_epoch(&self) -> HummockEpoch
pub fn is_read_committed(&self) -> bool